=================
Zonal analysis
=================

.. autoclass:: pylandstats.ZonalAnalysis
   :members:  __init__, compute_class_metrics_df, compute_landscape_metrics_df, compute_zonal_statistics_arr, compute_zonal_statistics_gdf, plot_metric, plot_landscapes

.. autoclass:: pylandstats.BufferAnalysis
   :members:  __init__, compute_class_metrics_df, compute_landscape_metrics_df, compute_zonal_statistics_arr, compute_zonal_statistics_gdf, plot_metric, plot_landscapes

.. autoclass:: pylandstats.ZonalGridAnalysis
   :members:  __init__, compute_class_metrics_df, compute_landscape_metrics_df, compute_zonal_statistics_arr, compute_zonal_statistics_gdf, plot_landscapes
